@@ -1,4 +1,4 @@
-# Copyright (c) 2000-2003 Dave Rolsky
+# Copyright (c) 2000-2004 Dave Rolsky
 # All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.  See the LICENSE
@@ -128,6 +128,13 @@ sub validate_pos (\@@)
 
     _validate_pos_depends(\@p, \@specs);
 
+    foreach ( grep { defined $p[$_] && ! ref $p[$_]
+                     && ref $specs[$_] && $specs[$_]{untaint} }
+              0..$bigger )
+    {
+        ($p[$_]) = $p[$_] =~ /(.+)/;
+    }
+
     return wantarray ? @p : \@p;
 }
 
@@ -351,6 +358,14 @@ sub validate (\@$)
               " $missing missing in call to $called\n" );
     }
 
+    # do untainting after we know everything passed
+    foreach my $key ( grep { defined $p->{$_} && ! ref $p->{$_}
+                             && ref $specs->{$_} && $specs->{$_}{untaint} }
+                      keys %$p )
+    {
+        ($p->{$key}) = $p->{$key} =~ /(.+)/;
+    }
+
     return wantarray ? %$p : $p;
 }
 
@@ -417,10 +432,7 @@ sub _normalize_named
 
     if ( $options->{ignore_case} )
     {
-	foreach (keys %h)
-	{
-	    $h{ lc $_ } = delete $h{$_};
-	}
+        $h{ lc $_ } = delete $h{$_} for keys %h;
     }
 
     if ( $options->{strip_leading} )
@@ -679,4 +691,10 @@ Params::ValidatePP - pure Perl implementation of Params::Validate
 This is a pure Perl implementation of Params::Validate.  See the
 Params::Validate documentation for details.
 
+=head1 COPYRIGHT
+
+Copyright (c) 2004 David Rolsky.  All rights reserved.  This program
+is free software; you can redistribute it and/or modify it under the
+same terms as Perl itself.
+
 =cut
